//============================================================================
// Bare-Bones Tablet Interface for C++
//
//  Private Header File
//
//  Author:        William Baxter (baxter@cs.unc.edu)
//============================================================================
// (MIT License)
// Copyright (c) 2002--2009 William Baxter
// 
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
// BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//============================================================================

#ifndef _BB_TABLET_PRIV_H__
#define _BB_TABLET_PRIV_H__

#include <vector>
#include <string>
#include <list>
/**
 * @class _bbTabletCursor
 */
class _bbTabletCursor
{
public:
  // enum { PUCK, STYLUS, ERASER, PUCK2, STYLUS2, ERASER2 };
  std::string name;
  int nButtons;
  std::vector<std::string> buttonNames;
};

class _bbTabletInternalBase
{
public:
  _bbTabletInternalBase() 
    : m_lostPackets(0), m_throwAwayOldPackets(false)
  {}
  ~_bbTabletInternalBase() {}
  long m_lostPackets;
  bool m_throwAwayOldPackets;

  typedef std::list<bbTabletObserver*> ObserverList;
  ObserverList m_observers;

public:
  bool _addObserver( bbTabletObserver& obs);
  bool _removeObserver( bbTabletObserver& obs);
  void _callObservers( const bbTabletEvent& evt );
  bool _hasObservers() const { return !m_observers.empty(); }
  int  _getNumObservers() const { return m_observers.size(); }
};



// bbTabletEvent flags
enum {
  BBTEV_ORIENT_OK=1
};


#endif
